#ifndef DINVERCORE_HEADERS
#define DINVERCORE_HEADERS

// All headers of DinverCore library

#include "AbstractCondition.h"
#include "AbstractForward.h"
#include "ActiveModel.h"
#include "ActiveModels.h"
#include "ArtificialBeeColony.h"
#include "BatchRun.h"
#include "BestModels.h"
#include "DinverCoreDLLExport.h"
#include "DinverCoreEngine.h"
#include "DinverInterface.h"
#include "Generator.h"
#include "GeneratorModels.h"
#include "ImportanceSampling.h"
#include "Index.h"
#include "Model.h"
#include "ModelRepository.h"
#include "ModelSet.h"
#include "NewModel.h"
#include "ParamCondition.h"
#include "ParamSpaceScript.h"
#include "Parameter.h"
#include "ParameterGrid.h"
#include "ParentIndex.h"
#include "PdfCurve.h"
#include "QuadraticCondition.h"
#include "RealSpace.h"
#include "ReportReader.h"
#include "ReportWriter.h"
#include "ScaledModels.h"
#include "SimpleCondition.h"
#include "Simplex.h"
#include "SumCondition.h"
#include "TemporaryDirectory.h"
#include "VoronoiNavigator.h"
#include "XMLDinver.h"
#include "XMLDinverContext.h"
#include "XMLDinverHeader.h"
#include "XMLVirtualPlugin.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace DinverCore;
#endif

#endif // DINVERCORE_HEADERS
